@@ -1,9 +1,11 @@
+import json
+
 import aiohttp
 import requests
 
-from .errors import ServiceUnavailable, RateLimited, Unauthorized, NotFound
+from .errors import ServiceUnavailable, RateLimited, Unauthorized, NotFound, Forbidden
 
-BASE_URL = 'https://fortnite-api.com/v2/'
+BASE_URL = 'https://fortnite-api.com/'
 
 
 class SyncHTTPClient:
@@ -19,7 +21,11 @@ class SyncHTTPClient:
 
     def get(self, endpoint, params=None):
         response = requests.get(BASE_URL + endpoint, params=params, headers=self.headers)
-        data = response.json()
+        print(response.url)
+        try:
+            data = response.json()
+        except json.JSONDecodeError:
+            data = {'error': response.text}
         if response.status_code == 200:
             return data
         elif response.status_code == 401:
@@ -49,13 +55,18 @@ class AsyncHTTPClient:
     async def get(self, endpoint, params=None):
         async with aiohttp.ClientSession() as session:
             async with session.get(BASE_URL + endpoint, params=params, headers=self.headers) as response:
-                data = await response.json()
+                try:
+                    data = await response.json()
+                except aiohttp.ContentTypeError:
+                    data = {'error': await response.text()}
                 if response.status == 200:
                     return data
                 if response.status == 401:
                     raise Unauthorized(data.get('error', 'Error message not provided!'))
-                elif response.status == 404:
+                elif response.status == 403:
                     raise NotFound(data.get('error', 'Error message not provided!'))
+                elif response.status == 404:
+                    raise Forbidden(data.get('error', 'Error message not provided!'))
                 elif response.status == 429:
                     raise RateLimited(data.get('error', 'Error message not provided!'))
                 elif response.status == 503:
